summaryrefslogtreecommitdiffstats
path: root/net/http/partial_data.cc
diff options
context:
space:
mode:
Diffstat (limited to 'net/http/partial_data.cc')
-rw-r--r--net/http/partial_data.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/net/http/partial_data.cc b/net/http/partial_data.cc
index a453ba4..247d76b 100644
--- a/net/http/partial_data.cc
+++ b/net/http/partial_data.cc
@@ -8,7 +8,7 @@
#include "base/bind_helpers.h"
#include "base/format_macros.h"
#include "base/logging.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
@@ -90,8 +90,8 @@ int PartialData::Core::GetAvailableRange(disk_cache::Entry* entry, int64 offset,
}
void PartialData::Core::OnIOComplete(int result) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422516 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422516 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422516 PartialData::Core::OnIOComplete"));